| create_model | R Documentation |
Create a model from a Modelfile
create_model(
model,
from = NULL,
template = NULL,
renderer = NULL,
parser = NULL,
license = NULL,
system = NULL,
parameters = NULL,
messages = NULL,
quantize = NULL,
stream = TRUE,
...,
server = NULL,
verbose = getOption("rollama_verbose", default = interactive())
)
model |
name of the model to create |
from |
existing model to create from |
template |
prompt template to use for the model |
renderer |
name of the renderer to use for the model |
parser |
name of the parser to use for the model |
license |
license string or list of licenses for the model |
system |
system prompt to embed in the model |
parameters |
key-value parameters for the model |
messages |
message history to use for the model (array of ChatMessage objects) |
quantize |
quantization level to apply (e.g. |
stream |
stream status updates (default: |
... |
additional arguments (currently unused) |
server |
URL to one or several Ollama servers (not the API). Defaults to "http://localhost:11434". |
verbose |
Whether to print status messages to the Console. Either
|
Custom models are the way to save your system message and model
parameters in a dedicated shareable way. If you use show_model(), you can
look at the configuration of a model in the column modelfile. To get more
information and a list of valid parameters, check out
https://docs.ollama.com/modelfile. Most
options are also available through the query and chat functions, yet
are not persistent over sessions.
(invisible) a tibble with information about the created model
create_model("mario", from = "llama3.1", system = "You are mario from Super Mario Bros.")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.