Check if one or several models are installed on the server
Source:R/utils.r
check_model_installed.RdCheck if one or several models are installed on the server

R/utils.r
check_model_installed.RdCheck if one or several models are installed on the server